ics

package module
v0.0.0-...-19751d9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 28, 2026 License: MPL-2.0 Imports: 8 Imported by: 0

README

ics

Package ics provides functions for reading ics calendars.

Documentation

Index

Constants

const ISO8601Date string = "2006-01-02"

ISO8601Date represents a data in format 'yyyy-MM-dd' by returning Go format '2006-01-02'.

const ISO8601DateTime string = "2006-01-02 15:04:05"

ISO8601DateTime represents a date + time in format 'yyyy-MM-dd HH:mm:ss' by returning Go format '2006-01-02 15:04:05'.

const ISO8601Time string = "15:04:05"

ISO8601Time represents a time in format 'HH:mm:ss' by returning Go format '15:04:05'.

Variables

This section is empty.

Functions

func DateSliceContains

func DateSliceContains(slice []time.Time, value time.Time) bool

DateContains returns a boolean indicating whether any date part of time.Time slice contains the date part of value.

Types

type Event

type Event struct {
	UID           string
	Timestamp     time.Time
	Organizer     string
	Attendee      string
	Description   string
	Categories    string
	Class         string
	Created       string
	Summary       string
	Start         time.Time
	End           time.Time
	Location      string
	Status        string
	FreeBusy      string
	LastModified  time.Time
	URL           string
	RepeatRule    string
	ExcludedDates []time.Time
}

Event is a calendar event.

func GetEvents

func GetEvents(url string, username string, password string, startDate time.Time, endDate time.Time) []Event

GetEvents returns all events for the specified url having their starting moment between startDate and endDate.

func (Event) String

func (e Event) String() string

Jump to